==> connector-service-1.0.0-20200117.064209-130-sources.jar: com/bizvane/connectorservice/util/StringUtil.java <==
package com.bizvane.connectorservice.util;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class StringUtil {
    public StringUtil() {
    }

    public static String valueOf(Object o) {
        if (o == null) {
            return "";
        } else {
            String ov = o.toString().trim();
            return "null".equalsIgnoreCase(ov) ? "" : ov;
        }
    }

    public static boolean isNull(Object o) {
        if (o == null) {
            return true;
        } else {
            String to = valueOf(o);
            return to.trim().isEmpty() || to.trim().equals("");
        }
    }

    public static boolean isNotNull(Object o) {
        return !isNull(o);
    }

    public static boolean isDigital(String o) {
        Pattern pattern = Pattern.compile("\\s*\\d+\\s*$");
        Matcher isNum = pattern.matcher(o);
        return isNum.matches();
    }

    public static boolean isNumeric(String str) {
        Pattern pattern = Pattern.compile("\\s*-?[0-9]+(.[0-9]+)?\\s*$");
        Matcher isNum = pattern.matcher(str);
        return isNum.matches();
    }

    public static String valueOf(Object o, String defaultvalue) {
        String s = null;
        s = isNull(o) ? defaultvalue : valueOf(o);
        return s;
    }

    public static boolean isFullDate(Object o) {
        if (isNull(o)) {
            return false;
        } else {
            String str = valueOf(o).trim();
            Pattern pattern = Pattern.compile("^(\\s*\\d{2}|\\d{4})(\\-|/)\\d{1,2}(\\-|/)\\d{1,2}\\s+\\d{1,2}(\\:|\\：)\\d{1,2}(\\:|\\：)\\d{1,2}\\s*$");
            Matcher isNum = pattern.matcher(str);
            return isNum.matches();
        }
    }

    public static boolean isDate(Object o) {
        if (isNull(o)) {
            return false;
        } else {
            String str = valueOf(o).trim();
            Pattern pattern = Pattern.compile("^(\\s*\\d{2}|\\d{4})(\\-|/)\\d{1,2}(\\-|/)\\d{1,2}\\s*$");
            Matcher isNum = pattern.matcher(str);
            return isNum.matches();
        }
    }
}

==> connector-service-1.0.6-20210827.071116-9-sources.jar: com/bizvane/connectorservice/util/StringUtil.java <==
package com.bizvane.connectorservice.util;

import java.util.regex.Matcher;
import java.util.regex.Pattern;
/**
 * @author admin
 */
public class StringUtil {

    private static Pattern IS_DIGITAL = Pattern.compile("\\s*\\d+\\s*$");

    private static Pattern IS_NUMERIC = Pattern.compile("\\s*-?[0-9]+(.[0-9]+)?\\s*$");

    private static Pattern IS_FULL_DATE = Pattern.compile("^(\\s*\\d{2}|\\d{4})(\\-|/)\\d{1,2}(\\-|/)\\d{1,2}\\s+\\d{1,2}(\\:|\\：)\\d{1,2}(\\:|\\：)\\d{1,2}\\s*$");

    private static Pattern IS_DATE = Pattern.compile("^(\\s*\\d{2}|\\d{4})(\\-|/)\\d{1,2}(\\-|/)\\d{1,2}\\s*$");


    public StringUtil() {
    }

    public static String valueOf(Object o) {
        if (o == null) {
            return "";
        } else {
            String ov = o.toString().trim();
            return "null".equalsIgnoreCase(ov) ? "" : ov;
        }
    }

    public static boolean isNull(Object o) {
        if (o == null) {
            return true;
        } else {
            String to = valueOf(o);
            return to.trim().isEmpty() || "".equals(to.trim());
        }
    }

    public static boolean isNotNull(Object o) {
        return !isNull(o);
    }

    public static boolean isDigital(String o) {
        Matcher isNum = IS_DIGITAL.matcher(o);
        return isNum.matches();
    }

    public static boolean isNumeric(String str) {
        Matcher isNum = IS_NUMERIC.matcher(str);
        return isNum.matches();
    }

    public static String valueOf(Object o, String defaultvalue) {
        String s = null;
        s = isNull(o) ? defaultvalue : valueOf(o);
        return s;
    }

    public static boolean isFullDate(Object o) {
        if (isNull(o)) {
            return false;
        } else {
            String str = valueOf(o).trim();
            Matcher isNum = IS_FULL_DATE.matcher(str);
            return isNum.matches();
        }
    }

    public static boolean isDate(Object o) {
        if (isNull(o)) {
            return false;
        } else {
            String str = valueOf(o).trim();
            Matcher isNum = IS_DATE.matcher(str);
            return isNum.matches();
        }
    }
}
